Module args

Structs

Output
StandardArgs

Enums

Command
OutputLocation

Functions

add_lang_argument
Add a --lang argument to the command. This argument will be optional if there is only one language
add_language_params_to_clap
Given a CliArgsSet for a language, use the name of the language and information about its configuration to populate a clap command with args specific to that language