pub struct Output {
pub file: Option<PathBuf>,
pub directory: Option<PathBuf>,
}Fields
file: Option<PathBuf>File to write output to. mtime will be preserved if the file contents don’t change
directory: Option<PathBuf>Folder to write output to. mtime will be preserved if the file contents don’t change
Implementations