pub struct StandardArgs {
pub subcommand: Option<Command>,
pub config: Option<PathBuf>,
pub directories: Vec<PathBuf>,
pub completions: Option<String>,
pub output: Output,
pub target_os: Option<Vec<String>>,
}Fields
subcommand: Option<Command>config: Option<PathBuf>Path to the config file for this typeshare
directories: Vec<PathBuf>The directories within which to recursively find and process rust files
completions: Option<String>output: Outputtarget_os: Option<Vec<String>>If given, only fields / types / variants matching at least one of these
OSes (per cfg(target_os)) will be emitted. If any --target-os
arguments are passed, they will override ALL target OSes passed via
a config file.
Generally, typeshare will err on the side of generating things. For
instance, given --target-os=ios and cfg(any(target_os="android", test)),
it WILL generate a type, because that type does exist on iOS in test
mode: there exists a configuration where that type exists on iOS.
In the future typeshare may be able to consider other cfgs.