CliArgsSet

Struct CliArgsSet 

pub struct CliArgsSet { /* private fields */ }
Support type for automatic CLI argument generation. A CliArgSet is a description of the fields for a given config type, but only the fields that can be effectively loaded from the command like (boolean flags and string or integer options)

Implementations

Source

impl CliArgsSet

pub fn iter(&self) -> impl Iterator<Item = ArgSpec<'_>> + '_

pub fn contains_key(&self, key: &str) -> bool