pub struct Config { /* private fields */ }Expand description
A partially parsed typeshare config file.
This contains a toml::Table for each language that was found in the config
file. The Config type on the Language trait can be further deserialized
from this toml table.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn config_for_language(&self, language: &str) -> &Table
pub fn config_for_language(&self, language: &str) -> &Table
Retrieve the config for the given language, by deserializing it into the given type. The deserialize implementation should be able to handle arbitrary missing keys by populating them with default values. Errors
pub fn store_config_for_language<T: Serialize>( &mut self, language: &str, config: &T, ) -> Result<()>