Source file parsing.
Structs
- Parsed
Data - The results of parsing Rust source input.
- Parser
Input - Input data for parsing each source file.
Enums
- Rust
Item - An enum that encapsulates units of code generation for Typeshare.
Analogous to
syn::Item, even though our variants are more limited.
Functions
- parse
- Parse the given Rust source string into
ParsedData. - parse_
input - Collect all the parsed sources into a mapping of crate name to parsed data.
- parser_
inputs - Walk the source folder and collect all parser inputs.