check_target_os

Function check_target_os 

pub fn check_target_os(attrs: &[Attribute], valid: &[&str]) -> bool
Check if the thing tagged by these attributes (type, field, whatever) is accepted by at least one of the given valid OSes. This returns true for a given OS so long as it isn’t explicitly rejected.