Struct ParsedData

pub struct ParsedData {
    pub structs: Vec<RustStruct>,
    pub enums: Vec<RustEnum>,
    pub aliases: Vec<RustTypeAlias>,
    pub consts: Vec<RustConst>,
    pub import_types: HashSet<ImportedType>,
}
The results of parsing Rust source input.

Fields

structs: Vec<RustStruct>

Structs defined in the source

enums: Vec<RustEnum>

Enums defined in the source

aliases: Vec<RustTypeAlias>

Type aliases defined in the source

consts: Vec<RustConst>

Constant variables defined in the source

import_types: HashSet<ImportedType>

Imports used by this file TODO: This is currently almost empty. Import computation was found to be pretty broken during the migration to Typeshare 2, so that part of multi-file output was stripped out to be restored later.

Implementations

Source

impl ParsedData

pub fn merge(&mut self, other: Self)

pub fn add(&mut self, item: RustItem)

pub fn all_type_names(&self) -> impl Iterator<Item = &TypeName> + use<'_>

pub fn sort_contents(&mut self)