Structs
Enums
Functions
- add_
lang_ argument - Add a
--langargument to the command. This argument will be optional if there is only one language - add_
language_ params_ to_ clap - Given a CliArgsSet for a language, use the name of the language and information about its configuration to populate a clap command with args specific to that language