Module driver
typeshare_
engine
0.4.1
Module driver
Module Items
Traits
Functions
In crate typeshare_
engine
typeshare_engine
Module
driver
Traits

Language
Helper
This trait is used by the driver macro to unify the ’config lifetime across all of the language types. I’m open to suggesstions for getting rid of this.
Language
Set
Functions

main_
body