Module driver

Structs

PersonalizeClap

Traits

LanguageHelper
This trait is used by the driver macro to unify the ’config lifetime across all of the language types. I’m open to suggesstions for getting rid of this.
LanguageSet

Functions

main_body