pub trait LanguageHelper {
type LanguageSet<'config>: LanguageSet<'config>;
}Expand description
This trait is used by the driver macro to unify the ’config lifetime across all of the language types. I’m open to suggesstions for getting rid of this.
Required Associated Types
type LanguageSet<'config>: LanguageSet<'config>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".