Module parser

Source file parsing.

Structs

ParsedData
The results of parsing Rust source input.
ParserInput
Input data for parsing each source file.

Enums

RustItem
An enum that encapsulates units of code generation for Typeshare. Analogous to syn::Item, even though our variants are more limited.

Functions

parse
Parse the given Rust source string into ParsedData.
parse_input
Collect all the parsed sources into a mapping of crate name to parsed data.
parser_inputs
Walk the source folder and collect all parser inputs.